@@ -6,6 +6,8 @@ from asiapay import views
 
 urlpatterns = patterns(
     '',
+    url(r'^pay-now/$', views.PaymentView.as_view(),
+        name='asiapay-pay-now'),
     url(r'^data-feed/$', views.DataFeedView.as_view(),
         name='asiapay-data-feed'),
     url(r'^success/$', views.SuccessResponseView.as_view(),
